@@ -1,12 +1,54 @@
 import inspect
 import json
+import logging
+
+import numpy as np
 
 from autoconf.class_path import get_class_path, get_class
 
+logger = logging.getLogger(
+    __name__
+)
+
+
+def nd_array_as_dict(
+        obj: np.ndarray
+) -> dict:
+    """
+    Converts a numpy array to a dictionary representation.
+    """
+    return {
+        "type": "numpy.ndarray",
+        "array": obj.tolist(),
+        "dtype": str(obj.dtype),
+    }
+
+
+def nd_array_from_dict(
+        nd_array_dict: dict
+) -> np.ndarray:
+    """
+    Converts a dictionary representation back to a numpy array.
+    """
+    return np.array(
+        nd_array_dict["array"],
+        dtype=getattr(
+            np, nd_array_dict["dtype"]
+        )
+    )
+
 
 def as_dict(
         obj
 ):
+    if isinstance(
+            obj, np.ndarray
+    ):
+        try:
+            return nd_array_as_dict(obj)
+        except Exception as e:
+            logger.info(e)
+
     if isinstance(
             obj, list
     ):
@@ -25,6 +67,7 @@ def as_dict(
             obj.__init__
         ).args[1:]
     }
+
     return {
         "type": get_class_path(
             obj.__class__
@@ -84,6 +127,10 @@ class Dictable:
                 "type"
             )
         )
+
+        if cls is np.ndarray:
+            return nd_array_from_dict(cls_dict)
+
         # noinspection PyArgumentList
         return cls(
             **{
@@ -111,8 +158,7 @@ class Dictable:
         with open(file_path, "r+") as f:
             cls_dict = json.load(f)
 
-        return cls.from_dict(cls_dict=cls_dict)
-
+        return cls.from_dict(cls_dict)
 
     def output_to_json(self, file_path: str):
         """
